@@ -5,14 +5,17 @@
 
 # License: BSD 3 clause
 
-import numpy as np
+import numbers
 import warnings
 
+import numpy as np
+
 from ..exceptions import ConvergenceWarning
 from ..base import BaseEstimator, ClusterMixin
 from ..utils import as_float_array, check_random_state
+from ..utils import check_scalar
 from ..utils.deprecation import deprecated
-from ..utils.validation import check_is_fitted, _deprecate_positional_args
+from ..utils.validation import check_is_fitted
 from ..metrics import euclidean_distances
 from ..metrics import pairwise_distances_argmin
 from .._config import config_context
@@ -32,10 +35,18 @@ def _equal_similarities_and_preferences(S, preference):
     return all_equal_preferences() and all_equal_similarities()
 
 
-@_deprecate_positional_args
-def affinity_propagation(S, *, preference=None, convergence_iter=15,
-                         max_iter=200, damping=0.5, copy=True, verbose=False,
-                         return_n_iter=False, random_state='warn'):
+def affinity_propagation(
+    S,
+    *,
+    preference=None,
+    convergence_iter=15,
+    max_iter=200,
+    damping=0.5,
+    copy=True,
+    verbose=False,
+    return_n_iter=False,
+    random_state=None,
+):
     """Perform Affinity Propagation Clustering of data.
 
     Read more in the :ref:`User Guide <affinity_propagation>`.
@@ -75,7 +86,7 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
     return_n_iter : bool, default=False
         Whether or not to return the number of iterations.
 
-    random_state : int, RandomState instance or None, default=0
+    random_state : int, RandomState instance or None, default=None
         Pseudo-random number generator to control the starting state.
         Use an int for reproducible results across function calls.
         See the :term:`Glossary <random_state>`.
@@ -124,40 +135,33 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
 
     if preference is None:
         preference = np.median(S)
-    if damping < 0.5 or damping >= 1:
-        raise ValueError('damping must be >= 0.5 and < 1')
 
     preference = np.array(preference)
 
-    if (n_samples == 1 or
-            _equal_similarities_and_preferences(S, preference)):
+    if n_samples == 1 or _equal_similarities_and_preferences(S, preference):
         # It makes no sense to run the algorithm in this case, so return 1 or
         # n_samples clusters, depending on preferences
-        warnings.warn("All samples have mutually equal similarities. "
-                      "Returning arbitrary cluster center(s).")
-        if preference.flat[0] >= S.flat[n_samples - 1]:
-            return ((np.arange(n_samples), np.arange(n_samples), 0)
-                    if return_n_iter
-                    else (np.arange(n_samples), np.arange(n_samples)))
-        else:
-            return ((np.array([0]), np.array([0] * n_samples), 0)
-                    if return_n_iter
-                    else (np.array([0]), np.array([0] * n_samples)))
-
-    if random_state == 'warn':
         warnings.warn(
-            "'random_state' has been introduced in 0.23. It will be set to "
-            "None starting from 1.0 (renaming of 0.25) which means that "
-            "results will differ at every function call. Set 'random_state' "
-            "to None to silence this warning, or to 0 to keep the behavior of "
-            "versions <0.23.",
-            FutureWarning
+            "All samples have mutually equal similarities. "
+            "Returning arbitrary cluster center(s)."
         )
-        random_state = 0
+        if preference.flat[0] >= S.flat[n_samples - 1]:
+            return (
+                (np.arange(n_samples), np.arange(n_samples), 0)
+                if return_n_iter
+                else (np.arange(n_samples), np.arange(n_samples))
+            )
+        else:
+            return (
+                (np.array([0]), np.array([0] * n_samples), 0)
+                if return_n_iter
+                else (np.array([0]), np.array([0] * n_samples))
+            )
+
     random_state = check_random_state(random_state)
 
     # Place preference on the diagonal of S
-    S.flat[::(n_samples + 1)] = preference
+    S.flat[:: (n_samples + 1)] = preference
 
     A = np.zeros((n_samples, n_samples))
     R = np.zeros((n_samples, n_samples))  # Initialize messages
@@ -165,8 +169,9 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
     tmp = np.zeros((n_samples, n_samples))
 
     # Remove degeneracies
-    S += ((np.finfo(S.dtype).eps * S + np.finfo(S.dtype).tiny * 100) *
-          random_state.randn(n_samples, n_samples))
+    S += (
+        np.finfo(S.dtype).eps * S + np.finfo(S.dtype).tiny * 100
+    ) * random_state.randn(n_samples, n_samples)
 
     # Execute parallel affinity propagation updates
     e = np.zeros((n_samples, convergence_iter))
@@ -192,13 +197,13 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
 
         # tmp = Rp; compute availabilities
         np.maximum(R, 0, tmp)
-        tmp.flat[::n_samples + 1] = R.flat[::n_samples + 1]
+        tmp.flat[:: n_samples + 1] = R.flat[:: n_samples + 1]
 
         # tmp = -Anew
         tmp -= np.sum(tmp, axis=0)
         dA = np.diag(tmp).copy()
         tmp.clip(0, np.inf, tmp)
-        tmp.flat[::n_samples + 1] = dA
+        tmp.flat[:: n_samples + 1] = dA
 
         # Damping
         tmp *= 1 - damping
@@ -212,8 +217,7 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
 
         if it >= convergence_iter:
             se = np.sum(e, axis=1)
-            unconverged = (np.sum((se == convergence_iter) + (se == 0))
-                           != n_samples)
+            unconverged = np.sum((se == convergence_iter) + (se == 0)) != n_samples
             if (not unconverged and (K > 0)) or (it == max_iter):
                 never_converged = False
                 if verbose:
@@ -243,8 +247,11 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
         cluster_centers_indices = np.unique(labels)
         labels = np.searchsorted(cluster_centers_indices, labels)
     else:
-        warnings.warn("Affinity propagation did not converge, this model "
-                      "will not have any cluster centers.", ConvergenceWarning)
+        warnings.warn(
+            "Affinity propagation did not converge, this model "
+            "will not have any cluster centers.",
+            ConvergenceWarning,
+        )
         labels = np.array([-1] * n_samples)
         cluster_centers_indices = []
 
@@ -256,6 +263,7 @@ def affinity_propagation(S, *, preference=None, convergence_iter=15,
 
 ###############################################################################
 
+
 class AffinityPropagation(ClusterMixin, BaseEstimator):
     """Perform Affinity Propagation Clustering of data.
 
@@ -264,7 +272,7 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
     Parameters
     ----------
     damping : float, default=0.5
-        Damping factor (between 0.5 and 1) is the extent to
+        Damping factor in the range `[0.5, 1.0)` is the extent to
         which the current value is maintained relative to
         incoming values (weighted 1 - damping). This in order
         to avoid numerical oscillations when updating these
@@ -295,7 +303,7 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
     verbose : bool, default=False
         Whether to be verbose.
 
-    random_state : int, RandomState instance or None, default=0
+    random_state : int, RandomState instance or None, default=None
         Pseudo-random number generator to control the starting state.
         Use an int for reproducible results across function calls.
         See the :term:`Glossary <random_state>`.
@@ -320,6 +328,29 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
     n_iter_ : int
         Number of iterations taken to converge.
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
+    See Also
+    --------
+    AgglomerativeClustering : Recursively merges the pair of
+        clusters that minimally increases a given linkage distance.
+    FeatureAgglomeration : Similar to AgglomerativeClustering,
+        but recursively merges features instead of samples.
+    KMeans : K-Means clustering.
+    MiniBatchKMeans : Mini-Batch K-Means clustering.
+    MeanShift : Mean shift clustering using a flat kernel.
+    SpectralClustering : Apply clustering to a projection
+        of the normalized Laplacian.
+
     Notes
     -----
     For an example, see :ref:`examples/cluster/plot_affinity_propagation.py
@@ -362,10 +393,19 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
     array([[1, 2],
            [4, 2]])
     """
-    @_deprecate_positional_args
-    def __init__(self, *, damping=.5, max_iter=200, convergence_iter=15,
-                 copy=True, preference=None, affinity='euclidean',
-                 verbose=False, random_state='warn'):
+
+    def __init__(
+        self,
+        *,
+        damping=0.5,
+        max_iter=200,
+        convergence_iter=15,
+        copy=True,
+        preference=None,
+        affinity="euclidean",
+        verbose=False,
+        random_state=None,
+    ):
 
         self.damping = damping
         self.max_iter = max_iter
@@ -378,14 +418,16 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
 
     # TODO: Remove in 1.1
     # mypy error: Decorated property not supported
-    @deprecated("Attribute _pairwise was deprecated in "  # type: ignore
-                "version 0.24 and will be removed in 1.1 (renaming of 0.26).")
+    @deprecated(  # type: ignore
+        "Attribute `_pairwise` was deprecated in "
+        "version 0.24 and will be removed in 1.1 (renaming of 0.26)."
+    )
     @property
     def _pairwise(self):
         return self.affinity == "precomputed"
 
     def _more_tags(self):
-        return {'pairwise': self.affinity == 'precomputed'}
+        return {"pairwise": self.affinity == "precomputed"}
 
     def fit(self, X, y=None):
         """Fit the clustering from features, or affinity matrix.
@@ -404,29 +446,54 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
         Returns
         -------
         self
-
+            Returns the instance itself.
         """
         if self.affinity == "precomputed":
             accept_sparse = False
         else:
-            accept_sparse = 'csr'
+            accept_sparse = "csr"
         X = self._validate_data(X, accept_sparse=accept_sparse)
         if self.affinity == "precomputed":
             self.affinity_matrix_ = X
         elif self.affinity == "euclidean":
             self.affinity_matrix_ = -euclidean_distances(X, squared=True)
         else:
-            raise ValueError("Affinity must be 'precomputed' or "
-                             "'euclidean'. Got %s instead"
-                             % str(self.affinity))
+            raise ValueError(
+                "Affinity must be 'precomputed' or 'euclidean'. Got %s instead"
+                % str(self.affinity)
+            )
 
-        self.cluster_centers_indices_, self.labels_, self.n_iter_ = \
-            affinity_propagation(
-                self.affinity_matrix_, preference=self.preference,
-                max_iter=self.max_iter,
-                convergence_iter=self.convergence_iter, damping=self.damping,
-                copy=self.copy, verbose=self.verbose, return_n_iter=True,
-                random_state=self.random_state)
+        check_scalar(
+            self.damping,
+            "damping",
+            target_type=numbers.Real,
+            min_val=0.5,
+            max_val=1,
+            include_boundaries="left",
+        )
+        check_scalar(self.max_iter, "max_iter", target_type=numbers.Integral, min_val=1)
+        check_scalar(
+            self.convergence_iter,
+            "convergence_iter",
+            target_type=numbers.Integral,
+            min_val=1,
+        )
+
+        (
+            self.cluster_centers_indices_,
+            self.labels_,
+            self.n_iter_,
+        ) = affinity_propagation(
+            self.affinity_matrix_,
+            preference=self.preference,
+            max_iter=self.max_iter,
+            convergence_iter=self.convergence_iter,
+            damping=self.damping,
+            copy=self.copy,
+            verbose=self.verbose,
+            return_n_iter=True,
+            random_state=self.random_state,
+        )
 
         if self.affinity != "precomputed":
             self.cluster_centers_ = X[self.cluster_centers_indices_].copy()
@@ -448,23 +515,26 @@ class AffinityPropagation(ClusterMixin, BaseEstimator):
             Cluster labels.
         """
         check_is_fitted(self)
-        X = self._validate_data(X, reset=False)
+        X = self._validate_data(X, reset=False, accept_sparse="csr")
         if not hasattr(self, "cluster_centers_"):
-            raise ValueError("Predict method is not supported when "
-                             "affinity='precomputed'.")
+            raise ValueError(
+                "Predict method is not supported when affinity='precomputed'."
+            )
 
         if self.cluster_centers_.shape[0] > 0:
             with config_context(assume_finite=True):
                 return pairwise_distances_argmin(X, self.cluster_centers_)
         else:
-            warnings.warn("This model does not have any cluster centers "
-                          "because affinity propagation did not converge. "
-                          "Labeling every sample as '-1'.", ConvergenceWarning)
+            warnings.warn(
+                "This model does not have any cluster centers "
+                "because affinity propagation did not converge. "
+                "Labeling every sample as '-1'.",
+                ConvergenceWarning,
+            )
             return np.array([-1] * X.shape[0])
 
     def fit_predict(self, X, y=None):
-        """Fit the clustering from features or affinity matrix, and return
-        cluster labels.
+        """Fit clustering from features/affinity matrix; return cluster labels.
 
         Parameters
         ----------
