@@ -8,12 +8,12 @@ import numpy as np
 
 from ..base import BaseEstimator, RegressorMixin, clone
 from ..utils.validation import check_is_fitted
+from ..utils._tags import _safe_tags
 from ..utils import check_array, _safe_indexing
 from ..preprocessing import FunctionTransformer
-from ..utils.validation import _deprecate_positional_args
 from ..exceptions import NotFittedError
 
-__all__ = ['TransformedTargetRegressor']
+__all__ = ["TransformedTargetRegressor"]
 
 
 class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
@@ -83,6 +83,18 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
     transformer_ : object
         Transformer used in ``fit`` and ``predict``.
 
+    n_features_in_ : int
+        Number of features seen during :term:`fit`. Only defined if the
+        underlying regressor exposes such an attribute when fit.
+
+        .. versionadded:: 0.24
+
+    feature_names_in_ : ndarray of shape (`n_features_in_`,)
+        Names of features seen during :term:`fit`. Defined only when `X`
+        has feature names that are all strings.
+
+        .. versionadded:: 1.0
+
     Examples
     --------
     >>> import numpy as np
@@ -109,9 +121,16 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
     <sphx_glr_auto_examples_compose_plot_transformed_target.py>`.
 
     """
-    @_deprecate_positional_args
-    def __init__(self, regressor=None, *, transformer=None,
-                 func=None, inverse_func=None, check_inverse=True):
+
+    def __init__(
+        self,
+        regressor=None,
+        *,
+        transformer=None,
+        func=None,
+        inverse_func=None,
+        check_inverse=True,
+    ):
         self.regressor = regressor
         self.transformer = transformer
         self.func = func
@@ -125,19 +144,25 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
         check on a subset (optional).
 
         """
-        if (self.transformer is not None and
-                (self.func is not None or self.inverse_func is not None)):
-            raise ValueError("'transformer' and functions 'func'/"
-                             "'inverse_func' cannot both be set.")
+        if self.transformer is not None and (
+            self.func is not None or self.inverse_func is not None
+        ):
+            raise ValueError(
+                "'transformer' and functions 'func'/'inverse_func' cannot both be set."
+            )
         elif self.transformer is not None:
             self.transformer_ = clone(self.transformer)
         else:
             if self.func is not None and self.inverse_func is None:
-                raise ValueError("When 'func' is provided, 'inverse_func' must"
-                                 " also be provided")
+                raise ValueError(
+                    "When 'func' is provided, 'inverse_func' must also be provided"
+                )
             self.transformer_ = FunctionTransformer(
-                func=self.func, inverse_func=self.inverse_func, validate=True,
-                check_inverse=self.check_inverse)
+                func=self.func,
+                inverse_func=self.inverse_func,
+                validate=True,
+                check_inverse=self.check_inverse,
+            )
         # XXX: sample_weight is not currently passed to the
         # transformer. However, if transformer starts using sample_weight, the
         # code should be modified accordingly. At the time to consider the
@@ -147,12 +172,14 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
             idx_selected = slice(None, None, max(1, y.shape[0] // 10))
             y_sel = _safe_indexing(y, idx_selected)
             y_sel_t = self.transformer_.transform(y_sel)
-            if not np.allclose(y_sel,
-                               self.transformer_.inverse_transform(y_sel_t)):
-                warnings.warn("The provided functions or transformer are"
-                              " not strictly inverse of each other. If"
-                              " you are sure you want to proceed regardless"
-                              ", set 'check_inverse=False'", UserWarning)
+            if not np.allclose(y_sel, self.transformer_.inverse_transform(y_sel_t)):
+                warnings.warn(
+                    "The provided functions or transformer are"
+                    " not strictly inverse of each other. If"
+                    " you are sure you want to proceed regardless"
+                    ", set 'check_inverse=False'",
+                    UserWarning,
+                )
 
     def fit(self, X, y, **fit_params):
         """Fit the model according to the given training data.
@@ -160,8 +187,8 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
         Parameters
         ----------
         X : {array-like, sparse matrix} of shape (n_samples, n_features)
-            Training vector, where n_samples is the number of samples and
-            n_features is the number of features.
+            Training vector, where `n_samples` is the number of samples and
+            `n_features` is the number of features.
 
         y : array-like of shape (n_samples,)
             Target values.
@@ -175,8 +202,14 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
         -------
         self : object
         """
-        y = check_array(y, accept_sparse=False, force_all_finite=True,
-                        ensure_2d=False, dtype='numeric')
+        y = check_array(
+            y,
+            accept_sparse=False,
+            force_all_finite=True,
+            ensure_2d=False,
+            dtype="numeric",
+            allow_nd=True,
+        )
 
         # store the number of dimension of the target to predict an array of
         # similar shape at predict
@@ -200,15 +233,19 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
 
         if self.regressor is None:
             from ..linear_model import LinearRegression
+
             self.regressor_ = LinearRegression()
         else:
             self.regressor_ = clone(self.regressor)
 
         self.regressor_.fit(X, y_trans, **fit_params)
 
+        if hasattr(self.regressor_, "feature_names_in_"):
+            self.feature_names_in_ = self.regressor_.feature_names_in_
+
         return self
 
-    def predict(self, X):
+    def predict(self, X, **predict_params):
         """Predict using the base regressor, applying inverse.
 
         The regressor is used to predict and the ``inverse_func`` or
@@ -219,6 +256,10 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
         X : {array-like, sparse matrix} of shape (n_samples, n_features)
             Samples.
 
+        **predict_params : dict of str -> object
+            Parameters passed to the `predict` method of the underlying
+            regressor.
+
         Returns
         -------
         y_hat : ndarray of shape (n_samples,)
@@ -226,20 +267,31 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
 
         """
         check_is_fitted(self)
-        pred = self.regressor_.predict(X)
+        pred = self.regressor_.predict(X, **predict_params)
         if pred.ndim == 1:
-            pred_trans = self.transformer_.inverse_transform(
-                pred.reshape(-1, 1))
+            pred_trans = self.transformer_.inverse_transform(pred.reshape(-1, 1))
         else:
             pred_trans = self.transformer_.inverse_transform(pred)
-        if (self._training_dim == 1 and
-                pred_trans.ndim == 2 and pred_trans.shape[1] == 1):
+        if (
+            self._training_dim == 1
+            and pred_trans.ndim == 2
+            and pred_trans.shape[1] == 1
+        ):
             pred_trans = pred_trans.squeeze(axis=1)
 
         return pred_trans
 
     def _more_tags(self):
-        return {'poor_score': True, 'no_validation': True}
+        regressor = self.regressor
+        if regressor is None:
+            from ..linear_model import LinearRegression
+
+            regressor = LinearRegression()
+
+        return {
+            "poor_score": True,
+            "multioutput": _safe_tags(regressor, key="multioutput"),
+        }
 
     @property
     def n_features_in_(self):
@@ -249,8 +301,9 @@ class TransformedTargetRegressor(RegressorMixin, BaseEstimator):
             check_is_fitted(self)
         except NotFittedError as nfe:
             raise AttributeError(
-                "{} object has no n_features_in_ attribute."
-                .format(self.__class__.__name__)
+                "{} object has no n_features_in_ attribute.".format(
+                    self.__class__.__name__
+                )
             ) from nfe
 
         return self.regressor_.n_features_in_
