@@ -12,6 +12,7 @@ import numpy as np
 from ...utils import check_random_state, check_array
 from ...base import BaseEstimator, TransformerMixin
 from ...utils.validation import check_is_fitted
+from ...utils._openmp_helpers import _openmp_effective_n_threads
 from ._binning import _map_to_bins
 from .common import X_DTYPE, X_BINNED_DTYPE, ALMOST_INF, X_BITSET_INNER_DTYPE
 from ._bitset import set_bitset_memoryview
@@ -47,7 +48,7 @@ def _find_binning_thresholds(col_data, max_bins):
     distinct_values = np.unique(col_data)
     if len(distinct_values) <= max_bins:
         midpoints = distinct_values[:-1] + distinct_values[1:]
-        midpoints *= .5
+        midpoints *= 0.5
     else:
         # We sort again the data in this case. We could compute
         # approximate midpoint percentiles using the output of
@@ -56,8 +57,9 @@ def _find_binning_thresholds(col_data, max_bins):
         # work on a fixed-size subsample of the full data.
         percentiles = np.linspace(0, 100, num=max_bins + 1)
         percentiles = percentiles[1:-1]
-        midpoints = np.percentile(col_data, percentiles,
-                                  interpolation='midpoint').astype(X_DTYPE)
+        midpoints = np.percentile(
+            col_data, percentiles, interpolation="midpoint"
+        ).astype(X_DTYPE)
         assert midpoints.shape[0] == max_bins - 1
 
     # We avoid having +inf thresholds: +inf thresholds are only allowed in
@@ -114,6 +116,11 @@ class _BinMapper(TransformerMixin, BaseEstimator):
         Pass an int for reproducible output across multiple
         function calls.
         See :term: `Glossary <random_state>`.
+    n_threads : int, default=None
+        Number of OpenMP threads to use. `_openmp_effective_n_threads` is called
+        to determine the effective number of threads use, which takes cgroups CPU
+        quotes into account. See the docstring of `_openmp_effective_n_threads`
+        for details.
 
     Attributes
     ----------
@@ -142,13 +149,22 @@ class _BinMapper(TransformerMixin, BaseEstimator):
         is less than ``n_bins - 1`` for a given feature, then there are
         empty (and unused) bins.
     """
-    def __init__(self, n_bins=256, subsample=int(2e5), is_categorical=None,
-                 known_categories=None, random_state=None):
+
+    def __init__(
+        self,
+        n_bins=256,
+        subsample=int(2e5),
+        is_categorical=None,
+        known_categories=None,
+        random_state=None,
+        n_threads=None,
+    ):
         self.n_bins = n_bins
         self.subsample = subsample
         self.is_categorical = is_categorical
         self.known_categories = known_categories
         self.random_state = random_state
+        self.n_threads = n_threads
 
     def fit(self, X, y=None):
         """Fit data X by computing the binning thresholds.
@@ -169,8 +185,11 @@ class _BinMapper(TransformerMixin, BaseEstimator):
         """
         if not (3 <= self.n_bins <= 256):
             # min is 3: at least 2 distinct bins and a missing values bin
-            raise ValueError('n_bins={} should be no smaller than 3 '
-                             'and no larger than 256.'.format(self.n_bins))
+            raise ValueError(
+                "n_bins={} should be no smaller than 3 and no larger than 256.".format(
+                    self.n_bins
+                )
+            )
 
         X = check_array(X, dtype=[X_DTYPE], force_all_finite=False)
         max_bins = self.n_bins - 1
@@ -183,8 +202,7 @@ class _BinMapper(TransformerMixin, BaseEstimator):
         if self.is_categorical is None:
             self.is_categorical_ = np.zeros(X.shape[1], dtype=np.uint8)
         else:
-            self.is_categorical_ = np.asarray(self.is_categorical,
-                                              dtype=np.uint8)
+            self.is_categorical_ = np.asarray(self.is_categorical, dtype=np.uint8)
 
         n_features = X.shape[1]
         known_categories = self.known_categories
@@ -202,7 +220,7 @@ class _BinMapper(TransformerMixin, BaseEstimator):
             if not is_categorical and known_cats is not None:
                 raise ValueError(
                     f"Feature {f_idx} isn't marked as a categorical feature, "
-                    f"but categories were passed."
+                    "but categories were passed."
                 )
 
         self.missing_values_bin_idx_ = self.n_bins - 1
@@ -224,8 +242,7 @@ class _BinMapper(TransformerMixin, BaseEstimator):
 
             self.bin_thresholds_.append(thresholds)
 
-        self.n_bins_non_missing_ = np.array(n_bins_non_missing,
-                                            dtype=np.uint32)
+        self.n_bins_non_missing_ = np.array(n_bins_non_missing, dtype=np.uint32)
         return self
 
     def transform(self, X):
@@ -252,13 +269,15 @@ class _BinMapper(TransformerMixin, BaseEstimator):
         check_is_fitted(self)
         if X.shape[1] != self.n_bins_non_missing_.shape[0]:
             raise ValueError(
-                'This estimator was fitted with {} features but {} got passed '
-                'to transform()'.format(self.n_bins_non_missing_.shape[0],
-                                        X.shape[1])
+                "This estimator was fitted with {} features but {} got passed "
+                "to transform()".format(self.n_bins_non_missing_.shape[0], X.shape[1])
             )
-        binned = np.zeros_like(X, dtype=X_BINNED_DTYPE, order='F')
-        _map_to_bins(X, self.bin_thresholds_, self.missing_values_bin_idx_,
-                     binned)
+
+        n_threads = _openmp_effective_n_threads(self.n_threads)
+        binned = np.zeros_like(X, dtype=X_BINNED_DTYPE, order="F")
+        _map_to_bins(
+            X, self.bin_thresholds_, self.missing_values_bin_idx_, n_threads, binned
+        )
         return binned
 
     def make_known_categories_bitsets(self):
@@ -280,18 +299,19 @@ class _BinMapper(TransformerMixin, BaseEstimator):
 
         f_idx_map = np.zeros(n_features, dtype=np.uint32)
         f_idx_map[categorical_features_indices] = np.arange(
-            n_categorical_features, dtype=np.uint32)
+            n_categorical_features, dtype=np.uint32
+        )
 
         known_categories = self.bin_thresholds_
 
-        known_cat_bitsets = np.zeros((n_categorical_features, 8),
-                                     dtype=X_BITSET_INNER_DTYPE)
+        known_cat_bitsets = np.zeros(
+            (n_categorical_features, 8), dtype=X_BITSET_INNER_DTYPE
+        )
 
         # TODO: complexity is O(n_categorical_features * 255). Maybe this is
         # worth cythonizing
         for mapped_f_idx, f_idx in enumerate(categorical_features_indices):
             for raw_cat_val in known_categories[f_idx]:
-                set_bitset_memoryview(known_cat_bitsets[mapped_f_idx],
-                                      raw_cat_val)
+                set_bitset_memoryview(known_cat_bitsets[mapped_f_idx], raw_cat_val)
 
         return known_cat_bitsets, f_idx_map
