@@ -15,6 +15,7 @@ the lower the better.
 #          Lars Buitinck
 #          Joel Nothman <joel.nothman@gmail.com>
 #          Noel Dawe <noel@dawe.me>
+#          Michal Karbownik <michakarbownik@gmail.com>
 # License: BSD 3 clause
 
 
@@ -27,11 +28,11 @@ from scipy.stats import rankdata
 
 from ..utils import assert_all_finite
 from ..utils import check_consistent_length
+from ..utils.validation import _check_sample_weight
 from ..utils import column_or_1d, check_array
 from ..utils.multiclass import type_of_target
 from ..utils.extmath import stable_cumsum
 from ..utils.sparsefuncs import count_nonzero
-from ..utils.validation import _deprecate_positional_args
 from ..exceptions import UndefinedMetricWarning
 from ..preprocessing import label_binarize
 from ..utils._encode import _encode, _unique
@@ -85,8 +86,10 @@ def auc(x, y):
     y = column_or_1d(y)
 
     if x.shape[0] < 2:
-        raise ValueError('At least 2 points are needed to compute'
-                         ' area under curve, but x.shape = %s' % x.shape)
+        raise ValueError(
+            "At least 2 points are needed to compute area under curve, but x.shape = %s"
+            % x.shape
+        )
 
     direction = 1
     dx = np.diff(x)
@@ -94,8 +97,7 @@ def auc(x, y):
         if np.all(dx <= 0):
             direction = -1
         else:
-            raise ValueError("x is neither increasing nor decreasing "
-                             ": {}.".format(x))
+            raise ValueError("x is neither increasing nor decreasing : {}.".format(x))
 
     area = direction * np.trapz(y, x)
     if isinstance(area, np.memmap):
@@ -106,9 +108,9 @@ def auc(x, y):
     return area
 
 
-@_deprecate_positional_args
-def average_precision_score(y_true, y_score, *, average="macro", pos_label=1,
-                            sample_weight=None):
+def average_precision_score(
+    y_true, y_score, *, average="macro", pos_label=1, sample_weight=None
+):
     """Compute average precision (AP) from prediction scores.
 
     AP summarizes a precision-recall curve as the weighted mean of precisions
@@ -196,10 +198,13 @@ def average_precision_score(y_true, y_score, *, average="macro", pos_label=1,
     >>> average_precision_score(y_true, y_scores)
     0.83...
     """
+
     def _binary_uninterpolated_average_precision(
-            y_true, y_score, pos_label=1, sample_weight=None):
+        y_true, y_score, pos_label=1, sample_weight=None
+    ):
         precision, recall, _ = precision_recall_curve(
-            y_true, y_score, pos_label=pos_label, sample_weight=sample_weight)
+            y_true, y_score, pos_label=pos_label, sample_weight=sample_weight
+        )
         # Return the step function integral
         # The following works because the last entry of precision is
         # guaranteed to be 1, as returned by precision_recall_curve
@@ -207,9 +212,11 @@ def average_precision_score(y_true, y_score, *, average="macro", pos_label=1,
 
     y_type = type_of_target(y_true)
     if y_type == "multilabel-indicator" and pos_label != 1:
-        raise ValueError("Parameter pos_label is fixed to 1 for "
-                         "multilabel-indicator y_true. Do not set "
-                         "pos_label or set pos_label to 1.")
+        raise ValueError(
+            "Parameter pos_label is fixed to 1 for "
+            "multilabel-indicator y_true. Do not set "
+            "pos_label or set pos_label to 1."
+        )
     elif y_type == "binary":
         # Convert to Python primitive type to avoid NumPy type / Python str
         # comparison. See https://github.com/numpy/numpy/issues/6784
@@ -219,10 +226,12 @@ def average_precision_score(y_true, y_score, *, average="macro", pos_label=1,
                 f"pos_label={pos_label} is not a valid label. It should be "
                 f"one of {present_labels}"
             )
-    average_precision = partial(_binary_uninterpolated_average_precision,
-                                pos_label=pos_label)
-    return _average_binary_score(average_precision, y_true, y_score,
-                                 average, sample_weight=sample_weight)
+    average_precision = partial(
+        _binary_uninterpolated_average_precision, pos_label=pos_label
+    )
+    return _average_binary_score(
+        average_precision, y_true, y_score, average, sample_weight=sample_weight
+    )
 
 
 def det_curve(y_true, y_score, pos_label=None, sample_weight=None):
@@ -272,7 +281,10 @@ def det_curve(y_true, y_score, pos_label=None, sample_weight=None):
 
     See Also
     --------
-    plot_det_curve : Plot detection error tradeoff (DET) curve.
+    DetCurveDisplay.from_estimator : Plot DET curve given an estimator and
+        some data.
+    DetCurveDisplay.from_predictions : Plot DET curve given the true and
+        predicted labels.
     DetCurveDisplay : DET curve visualization.
     roc_curve : Compute Receiver operating characteristic (ROC) curve.
     precision_recall_curve : Compute precision-recall curve.
@@ -291,22 +303,24 @@ def det_curve(y_true, y_score, pos_label=None, sample_weight=None):
     >>> thresholds
     array([0.35, 0.4 , 0.8 ])
     """
-    if len(np.unique(y_true)) != 2:
-        raise ValueError("Only one class present in y_true. Detection error "
-                         "tradeoff curve is not defined in that case.")
-
     fps, tps, thresholds = _binary_clf_curve(
         y_true, y_score, pos_label=pos_label, sample_weight=sample_weight
     )
 
+    if len(np.unique(y_true)) != 2:
+        raise ValueError(
+            "Only one class present in y_true. Detection error "
+            "tradeoff curve is not defined in that case."
+        )
+
     fns = tps[-1] - tps
     p_count = tps[-1]
     n_count = fps[-1]
 
     # start with false positives zero
     first_ind = (
-        fps.searchsorted(fps[0], side='right') - 1
-        if fps.searchsorted(fps[0], side='right') > 0
+        fps.searchsorted(fps[0], side="right") - 1
+        if fps.searchsorted(fps[0], side="right") > 0
         else None
     )
     # stop with false negatives zero
@@ -314,28 +328,25 @@ def det_curve(y_true, y_score, pos_label=None, sample_weight=None):
     sl = slice(first_ind, last_ind)
 
     # reverse the output such that list of false positives is decreasing
-    return (
-        fps[sl][::-1] / n_count,
-        fns[sl][::-1] / p_count,
-        thresholds[sl][::-1]
-    )
+    return (fps[sl][::-1] / n_count, fns[sl][::-1] / p_count, thresholds[sl][::-1])
 
 
 def _binary_roc_auc_score(y_true, y_score, sample_weight=None, max_fpr=None):
     """Binary roc auc score."""
     if len(np.unique(y_true)) != 2:
-        raise ValueError("Only one class present in y_true. ROC AUC score "
-                         "is not defined in that case.")
+        raise ValueError(
+            "Only one class present in y_true. ROC AUC score "
+            "is not defined in that case."
+        )
 
-    fpr, tpr, _ = roc_curve(y_true, y_score,
-                            sample_weight=sample_weight)
+    fpr, tpr, _ = roc_curve(y_true, y_score, sample_weight=sample_weight)
     if max_fpr is None or max_fpr == 1:
         return auc(fpr, tpr)
     if max_fpr <= 0 or max_fpr > 1:
         raise ValueError("Expected max_fpr in range (0, 1], got: %r" % max_fpr)
 
     # Add a single point at max_fpr by linear interpolation
-    stop = np.searchsorted(fpr, max_fpr, 'right')
+    stop = np.searchsorted(fpr, max_fpr, "right")
     x_interp = [fpr[stop - 1], fpr[stop]]
     y_interp = [tpr[stop - 1], tpr[stop]]
     tpr = np.append(tpr[:stop], np.interp(max_fpr, x_interp, y_interp))
@@ -344,14 +355,21 @@ def _binary_roc_auc_score(y_true, y_score, sample_weight=None, max_fpr=None):
 
     # McClish correction: standardize result to be 0.5 if non-discriminant
     # and 1 if maximal
-    min_area = 0.5 * max_fpr**2
+    min_area = 0.5 * max_fpr ** 2
     max_area = max_fpr
     return 0.5 * (1 + (partial_auc - min_area) / (max_area - min_area))
 
 
-@_deprecate_positional_args
-def roc_auc_score(y_true, y_score, *, average="macro", sample_weight=None,
-                  max_fpr=None, multi_class="raise", labels=None):
+def roc_auc_score(
+    y_true,
+    y_score,
+    *,
+    average="macro",
+    sample_weight=None,
+    max_fpr=None,
+    multi_class="raise",
+    labels=None,
+):
     """Compute Area Under the Receiver Operating Characteristic Curve (ROC AUC)
     from prediction scores.
 
@@ -476,7 +494,10 @@ def roc_auc_score(y_true, y_score, *, average="macro", sample_weight=None,
     --------
     average_precision_score : Area under the precision-recall curve.
     roc_curve : Compute Receiver operating characteristic (ROC) curve.
-    plot_roc_curve : Plot Receiver operating characteristic (ROC) curve.
+    RocCurveDisplay.from_estimator : Plot Receiver Operating Characteristic
+        (ROC) curve given an estimator and some data.
+    RocCurveDisplay.from_predictions : Plot Receiver Operating Characteristic
+        (ROC) curve given the true and predicted values.
 
     Examples
     --------
@@ -523,35 +544,45 @@ def roc_auc_score(y_true, y_score, *, average="macro", sample_weight=None,
     y_true = check_array(y_true, ensure_2d=False, dtype=None)
     y_score = check_array(y_score, ensure_2d=False)
 
-    if y_type == "multiclass" or (y_type == "binary" and
-                                  y_score.ndim == 2 and
-                                  y_score.shape[1] > 2):
+    if y_type == "multiclass" or (
+        y_type == "binary" and y_score.ndim == 2 and y_score.shape[1] > 2
+    ):
         # do not support partial ROC computation for multiclass
-        if max_fpr is not None and max_fpr != 1.:
-            raise ValueError("Partial AUC computation not available in "
-                             "multiclass setting, 'max_fpr' must be"
-                             " set to `None`, received `max_fpr={0}` "
-                             "instead".format(max_fpr))
-        if multi_class == 'raise':
+        if max_fpr is not None and max_fpr != 1.0:
+            raise ValueError(
+                "Partial AUC computation not available in "
+                "multiclass setting, 'max_fpr' must be"
+                " set to `None`, received `max_fpr={0}` "
+                "instead".format(max_fpr)
+            )
+        if multi_class == "raise":
             raise ValueError("multi_class must be in ('ovo', 'ovr')")
-        return _multiclass_roc_auc_score(y_true, y_score, labels,
-                                         multi_class, average, sample_weight)
+        return _multiclass_roc_auc_score(
+            y_true, y_score, labels, multi_class, average, sample_weight
+        )
     elif y_type == "binary":
         labels = np.unique(y_true)
         y_true = label_binarize(y_true, classes=labels)[:, 0]
-        return _average_binary_score(partial(_binary_roc_auc_score,
-                                             max_fpr=max_fpr),
-                                     y_true, y_score, average,
-                                     sample_weight=sample_weight)
+        return _average_binary_score(
+            partial(_binary_roc_auc_score, max_fpr=max_fpr),
+            y_true,
+            y_score,
+            average,
+            sample_weight=sample_weight,
+        )
     else:  # multilabel-indicator
-        return _average_binary_score(partial(_binary_roc_auc_score,
-                                             max_fpr=max_fpr),
-                                     y_true, y_score, average,
-                                     sample_weight=sample_weight)
+        return _average_binary_score(
+            partial(_binary_roc_auc_score, max_fpr=max_fpr),
+            y_true,
+            y_score,
+            average,
+            sample_weight=sample_weight,
+        )
 
 
-def _multiclass_roc_auc_score(y_true, y_score, labels,
-                              multi_class, average, sample_weight):
+def _multiclass_roc_auc_score(
+    y_true, y_score, labels, multi_class, average, sample_weight
+):
     """Multiclass roc auc score.
 
     Parameters
@@ -595,20 +626,23 @@ def _multiclass_roc_auc_score(y_true, y_score, labels,
     if not np.allclose(1, y_score.sum(axis=1)):
         raise ValueError(
             "Target scores need to be probabilities for multiclass "
-            "roc_auc, i.e. they should sum up to 1.0 over classes")
+            "roc_auc, i.e. they should sum up to 1.0 over classes"
+        )
 
     # validation for multiclass parameter specifications
     average_options = ("macro", "weighted")
     if average not in average_options:
-        raise ValueError("average must be one of {0} for "
-                         "multiclass problems".format(average_options))
+        raise ValueError(
+            "average must be one of {0} for multiclass problems".format(average_options)
+        )
 
     multiclass_options = ("ovo", "ovr")
     if multi_class not in multiclass_options:
-        raise ValueError("multi_class='{0}' is not supported "
-                         "for multiclass ROC AUC, multi_class must be "
-                         "in {1}".format(
-                                multi_class, multiclass_options))
+        raise ValueError(
+            "multi_class='{0}' is not supported "
+            "for multiclass ROC AUC, multi_class must be "
+            "in {1}".format(multi_class, multiclass_options)
+        )
 
     if labels is not None:
         labels = column_or_1d(labels)
@@ -620,34 +654,40 @@ def _multiclass_roc_auc_score(y_true, y_score, labels,
         if len(classes) != y_score.shape[1]:
             raise ValueError(
                 "Number of given labels, {0}, not equal to the number "
-                "of columns in 'y_score', {1}".format(
-                    len(classes), y_score.shape[1]))
+                "of columns in 'y_score', {1}".format(len(classes), y_score.shape[1])
+            )
         if len(np.setdiff1d(y_true, classes)):
-            raise ValueError(
-                "'y_true' contains labels not in parameter 'labels'")
+            raise ValueError("'y_true' contains labels not in parameter 'labels'")
     else:
         classes = _unique(y_true)
         if len(classes) != y_score.shape[1]:
             raise ValueError(
                 "Number of classes in y_true not equal to the number of "
-                "columns in 'y_score'")
+                "columns in 'y_score'"
+            )
 
     if multi_class == "ovo":
         if sample_weight is not None:
-            raise ValueError("sample_weight is not supported "
-                             "for multiclass one-vs-one ROC AUC, "
-                             "'sample_weight' must be None in this case.")
+            raise ValueError(
+                "sample_weight is not supported "
+                "for multiclass one-vs-one ROC AUC, "
+                "'sample_weight' must be None in this case."
+            )
         y_true_encoded = _encode(y_true, uniques=classes)
         # Hand & Till (2001) implementation (ovo)
-        return _average_multiclass_ovo_score(_binary_roc_auc_score,
-                                             y_true_encoded,
-                                             y_score, average=average)
+        return _average_multiclass_ovo_score(
+            _binary_roc_auc_score, y_true_encoded, y_score, average=average
+        )
     else:
         # ovr is same as multi-label
         y_true_multilabel = label_binarize(y_true, classes=classes)
-        return _average_binary_score(_binary_roc_auc_score, y_true_multilabel,
-                                     y_score, average,
-                                     sample_weight=sample_weight)
+        return _average_binary_score(
+            _binary_roc_auc_score,
+            y_true_multilabel,
+            y_score,
+            average,
+            sample_weight=sample_weight,
+        )
 
 
 def _binary_clf_curve(y_true, y_score, pos_label=None, sample_weight=None):
@@ -686,8 +726,7 @@ def _binary_clf_curve(y_true, y_score, pos_label=None, sample_weight=None):
     """
     # Check to make sure y_true is valid
     y_type = type_of_target(y_true)
-    if not (y_type == "binary" or
-            (y_type == "multiclass" and pos_label is not None)):
+    if not (y_type == "binary" or (y_type == "multiclass" and pos_label is not None)):
         raise ValueError("{0} format is not supported".format(y_type))
 
     check_consistent_length(y_true, y_score, sample_weight)
@@ -696,13 +735,19 @@ def _binary_clf_curve(y_true, y_score, pos_label=None, sample_weight=None):
     assert_all_finite(y_true)
     assert_all_finite(y_score)
 
+    # Filter out zero-weighted samples, as they should not impact the result
     if sample_weight is not None:
         sample_weight = column_or_1d(sample_weight)
+        sample_weight = _check_sample_weight(sample_weight, y_true)
+        nonzero_weight_mask = sample_weight != 0
+        y_true = y_true[nonzero_weight_mask]
+        y_score = y_score[nonzero_weight_mask]
+        sample_weight = sample_weight[nonzero_weight_mask]
 
     pos_label = _check_pos_label_consistency(pos_label, y_true)
 
     # make y_true a boolean vector
-    y_true = (y_true == pos_label)
+    y_true = y_true == pos_label
 
     # sort scores and corresponding truth values
     desc_score_indices = np.argsort(y_score, kind="mergesort")[::-1]
@@ -711,7 +756,7 @@ def _binary_clf_curve(y_true, y_score, pos_label=None, sample_weight=None):
     if sample_weight is not None:
         weight = sample_weight[desc_score_indices]
     else:
-        weight = 1.
+        weight = 1.0
 
     # y_score typically has many tied values. Here we extract
     # the indices associated with the distinct values. We also
@@ -730,9 +775,7 @@ def _binary_clf_curve(y_true, y_score, pos_label=None, sample_weight=None):
     return fps, tps, y_score[threshold_idxs]
 
 
-@_deprecate_positional_args
-def precision_recall_curve(y_true, probas_pred, *, pos_label=None,
-                           sample_weight=None):
+def precision_recall_curve(y_true, probas_pred, *, pos_label=None, sample_weight=None):
     """Compute precision-recall pairs for different probability thresholds.
 
     Note: this implementation is restricted to the binary classification task.
@@ -759,7 +802,9 @@ def precision_recall_curve(y_true, probas_pred, *, pos_label=None,
         pos_label should be explicitly given.
 
     probas_pred : ndarray of shape (n_samples,)
-        Estimated probabilities or output of a decision function.
+        Target scores, can either be probability estimates of the positive
+        class, or non-thresholded measure of decisions (as returned by
+        `decision_function` on some classifiers).
 
     pos_label : int or str, default=None
         The label of the positive class.
@@ -785,9 +830,10 @@ def precision_recall_curve(y_true, probas_pred, *, pos_label=None,
 
     See Also
     --------
-    plot_precision_recall_curve : Plot Precision Recall Curve for binary
-        classifiers.
-    PrecisionRecallDisplay : Precision Recall visualization.
+    PrecisionRecallDisplay.from_estimator : Plot Precision Recall Curve given
+        a binary classifier.
+    PrecisionRecallDisplay.from_predictions : Plot Precision Recall Curve
+        using predictions from a binary classifier.
     average_precision_score : Compute average precision from prediction scores.
     det_curve: Compute error rates for different probability thresholds.
     roc_curve : Compute Receiver operating characteristic (ROC) curve.
@@ -808,9 +854,9 @@ def precision_recall_curve(y_true, probas_pred, *, pos_label=None,
     array([0.35, 0.4 , 0.8 ])
 
     """
-    fps, tps, thresholds = _binary_clf_curve(y_true, probas_pred,
-                                             pos_label=pos_label,
-                                             sample_weight=sample_weight)
+    fps, tps, thresholds = _binary_clf_curve(
+        y_true, probas_pred, pos_label=pos_label, sample_weight=sample_weight
+    )
 
     precision = tps / (tps + fps)
     precision[np.isnan(precision)] = 0
@@ -823,9 +869,9 @@ def precision_recall_curve(y_true, probas_pred, *, pos_label=None,
     return np.r_[precision[sl], 1], np.r_[recall[sl], 0], thresholds[sl]
 
 
-@_deprecate_positional_args
-def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
-              drop_intermediate=True):
+def roc_curve(
+    y_true, y_score, *, pos_label=None, sample_weight=None, drop_intermediate=True
+):
     """Compute Receiver operating characteristic (ROC).
 
     Note: this implementation is restricted to the binary classification task.
@@ -876,8 +922,10 @@ def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
 
     See Also
     --------
-    plot_roc_curve : Plot Receiver operating characteristic (ROC) curve.
-    RocCurveDisplay : ROC Curve visualization.
+    RocCurveDisplay.from_estimator : Plot Receiver Operating Characteristic
+        (ROC) curve given an estimator and some data.
+    RocCurveDisplay.from_predictions : Plot Receiver Operating Characteristic
+        (ROC) curve given the true and predicted values.
     det_curve: Compute error rates for different probability thresholds.
     roc_auc_score : Compute the area under the ROC curve.
 
@@ -911,7 +959,8 @@ def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
 
     """
     fps, tps, thresholds = _binary_clf_curve(
-        y_true, y_score, pos_label=pos_label, sample_weight=sample_weight)
+        y_true, y_score, pos_label=pos_label, sample_weight=sample_weight
+    )
 
     # Attempt to drop thresholds corresponding to points in between and
     # collinear with other points. These are always suboptimal and do not
@@ -923,10 +972,9 @@ def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
     # but does not drop more complicated cases like fps = [1, 3, 7],
     # tps = [1, 2, 4]; there is no harm in keeping too many thresholds.
     if drop_intermediate and len(fps) > 2:
-        optimal_idxs = np.where(np.r_[True,
-                                      np.logical_or(np.diff(fps, 2),
-                                                    np.diff(tps, 2)),
-                                      True])[0]
+        optimal_idxs = np.where(
+            np.r_[True, np.logical_or(np.diff(fps, 2), np.diff(tps, 2)), True]
+        )[0]
         fps = fps[optimal_idxs]
         tps = tps[optimal_idxs]
         thresholds = thresholds[optimal_idxs]
@@ -938,17 +986,19 @@ def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
     thresholds = np.r_[thresholds[0] + 1, thresholds]
 
     if fps[-1] <= 0:
-        warnings.warn("No negative samples in y_true, "
-                      "false positive value should be meaningless",
-                      UndefinedMetricWarning)
+        warnings.warn(
+            "No negative samples in y_true, false positive value should be meaningless",
+            UndefinedMetricWarning,
+        )
         fpr = np.repeat(np.nan, fps.shape)
     else:
         fpr = fps / fps[-1]
 
     if tps[-1] <= 0:
-        warnings.warn("No positive samples in y_true, "
-                      "true positive value should be meaningless",
-                      UndefinedMetricWarning)
+        warnings.warn(
+            "No positive samples in y_true, true positive value should be meaningless",
+            UndefinedMetricWarning,
+        )
         tpr = np.repeat(np.nan, tps.shape)
     else:
         tpr = tps / tps[-1]
@@ -956,9 +1006,7 @@ def roc_curve(y_true, y_score, *, pos_label=None, sample_weight=None,
     return fpr, tpr, thresholds
 
 
-@_deprecate_positional_args
-def label_ranking_average_precision_score(y_true, y_score, *,
-                                          sample_weight=None):
+def label_ranking_average_precision_score(y_true, y_score, *, sample_weight=None):
     """Compute ranking-based average precision.
 
     Label ranking average precision (LRAP) is the average over each ground
@@ -1011,8 +1059,9 @@ def label_ranking_average_precision_score(y_true, y_score, *,
 
     # Handle badly formatted array and the degenerate case with one label
     y_type = type_of_target(y_true)
-    if (y_type != "multilabel-indicator" and
-            not (y_type == "binary" and y_true.ndim == 2)):
+    if y_type != "multilabel-indicator" and not (
+        y_type == "binary" and y_true.ndim == 2
+    ):
         raise ValueError("{0} format is not supported".format(y_type))
 
     y_true = csr_matrix(y_true)
@@ -1020,18 +1069,18 @@ def label_ranking_average_precision_score(y_true, y_score, *,
 
     n_samples, n_labels = y_true.shape
 
-    out = 0.
+    out = 0.0
     for i, (start, stop) in enumerate(zip(y_true.indptr, y_true.indptr[1:])):
         relevant = y_true.indices[start:stop]
 
-        if (relevant.size == 0 or relevant.size == n_labels):
+        if relevant.size == 0 or relevant.size == n_labels:
             # If all labels are relevant or unrelevant, the score is also
             # equal to 1. The label ranking has no meaning.
-            aux = 1.
+            aux = 1.0
         else:
             scores_i = y_score[i]
-            rank = rankdata(scores_i, 'max')[relevant]
-            L = rankdata(scores_i[relevant], 'max')
+            rank = rankdata(scores_i, "max")[relevant]
+            L = rankdata(scores_i[relevant], "max")
             aux = (L / rank).mean()
 
         if sample_weight is not None:
@@ -1046,7 +1095,6 @@ def label_ranking_average_precision_score(y_true, y_score, *,
     return out
 
 
-@_deprecate_positional_args
 def coverage_error(y_true, y_score, *, sample_weight=None):
     """Coverage error measure.
 
@@ -1106,7 +1154,6 @@ def coverage_error(y_true, y_score, *, sample_weight=None):
     return np.average(coverage, weights=sample_weight)
 
 
-@_deprecate_positional_args
 def label_ranking_loss(y_true, y_score, *, sample_weight=None):
     """Compute Ranking loss measure.
 
@@ -1146,7 +1193,7 @@ def label_ranking_loss(y_true, y_score, *, sample_weight=None):
            Mining multi-label data. In Data mining and knowledge discovery
            handbook (pp. 667-685). Springer US.
     """
-    y_true = check_array(y_true, ensure_2d=False, accept_sparse='csr')
+    y_true = check_array(y_true, ensure_2d=False, accept_sparse="csr")
     y_score = check_array(y_score, ensure_2d=False)
     check_consistent_length(y_true, y_score, sample_weight)
 
@@ -1164,35 +1211,31 @@ def label_ranking_loss(y_true, y_score, *, sample_weight=None):
     loss = np.zeros(n_samples)
     for i, (start, stop) in enumerate(zip(y_true.indptr, y_true.indptr[1:])):
         # Sort and bin the label scores
-        unique_scores, unique_inverse = np.unique(y_score[i],
-                                                  return_inverse=True)
+        unique_scores, unique_inverse = np.unique(y_score[i], return_inverse=True)
         true_at_reversed_rank = np.bincount(
-            unique_inverse[y_true.indices[start:stop]],
-            minlength=len(unique_scores))
-        all_at_reversed_rank = np.bincount(unique_inverse,
-                                           minlength=len(unique_scores))
+            unique_inverse[y_true.indices[start:stop]], minlength=len(unique_scores)
+        )
+        all_at_reversed_rank = np.bincount(unique_inverse, minlength=len(unique_scores))
         false_at_reversed_rank = all_at_reversed_rank - true_at_reversed_rank
 
         # if the scores are ordered, it's possible to count the number of
         # incorrectly ordered paires in linear time by cumulatively counting
         # how many false labels of a given score have a score higher than the
         # accumulated true labels with lower score.
-        loss[i] = np.dot(true_at_reversed_rank.cumsum(),
-                         false_at_reversed_rank)
+        loss[i] = np.dot(true_at_reversed_rank.cumsum(), false_at_reversed_rank)
 
     n_positives = count_nonzero(y_true, axis=1)
     with np.errstate(divide="ignore", invalid="ignore"):
-        loss /= ((n_labels - n_positives) * n_positives)
+        loss /= (n_labels - n_positives) * n_positives
 
     # When there is no positive or no negative labels, those values should
     # be consider as correct, i.e. the ranking doesn't matter.
-    loss[np.logical_or(n_positives == 0, n_positives == n_labels)] = 0.
+    loss[np.logical_or(n_positives == 0, n_positives == n_labels)] = 0.0
 
     return np.average(loss, weights=sample_weight)
 
 
-def _dcg_sample_scores(y_true, y_score, k=None,
-                       log_base=2, ignore_ties=False):
+def _dcg_sample_scores(y_true, y_score, k=None, log_base=2, ignore_ties=False):
     """Compute Discounted Cumulative Gain.
 
     Sum the true scores ranked in the order induced by the predicted scores,
@@ -1213,7 +1256,7 @@ def _dcg_sample_scores(y_true, y_score, k=None,
         "decision_function" on some classifiers).
 
     k : int, default=None
-        Only consider the highest k scores in the ranking. If None, use all
+        Only consider the highest k scores in the ranking. If `None`, use all
         outputs.
 
     log_base : float, default=2
@@ -1244,8 +1287,10 @@ def _dcg_sample_scores(y_true, y_score, k=None,
         cumulative_gains = discount.dot(ranked.T)
     else:
         discount_cumsum = np.cumsum(discount)
-        cumulative_gains = [_tie_averaged_dcg(y_t, y_s, discount_cumsum)
-                            for y_t, y_s in zip(y_true, y_score)]
+        cumulative_gains = [
+            _tie_averaged_dcg(y_t, y_s, discount_cumsum)
+            for y_t, y_s in zip(y_true, y_score)
+        ]
         cumulative_gains = np.asarray(cumulative_gains)
     return cumulative_gains
 
@@ -1287,8 +1332,7 @@ def _tie_averaged_dcg(y_true, y_score, discount_cumsum):
     European conference on information retrieval (pp. 414-421). Springer,
     Berlin, Heidelberg.
     """
-    _, inv, counts = np.unique(
-        - y_score, return_inverse=True, return_counts=True)
+    _, inv, counts = np.unique(-y_score, return_inverse=True, return_counts=True)
     ranked = np.zeros(len(counts))
     np.add.at(ranked, inv, y_true)
     ranked /= counts
@@ -1301,17 +1345,22 @@ def _tie_averaged_dcg(y_true, y_score, discount_cumsum):
 
 def _check_dcg_target_type(y_true):
     y_type = type_of_target(y_true)
-    supported_fmt = ("multilabel-indicator", "continuous-multioutput",
-                     "multiclass-multioutput")
+    supported_fmt = (
+        "multilabel-indicator",
+        "continuous-multioutput",
+        "multiclass-multioutput",
+    )
     if y_type not in supported_fmt:
         raise ValueError(
             "Only {} formats are supported. Got {} instead".format(
-                supported_fmt, y_type))
+                supported_fmt, y_type
+            )
+        )
 
 
-@_deprecate_positional_args
-def dcg_score(y_true, y_score, *, k=None,
-              log_base=2, sample_weight=None, ignore_ties=False):
+def dcg_score(
+    y_true, y_score, *, k=None, log_base=2, sample_weight=None, ignore_ties=False
+):
     """Compute Discounted Cumulative Gain.
 
     Sum the true scores ranked in the order induced by the predicted scores,
@@ -1343,7 +1392,7 @@ def dcg_score(y_true, y_score, *, k=None,
         sharper discount (top results are more important).
 
     sample_weight : ndarray of shape (n_samples,), default=None
-        Sample weights. If None, all samples are given the same weight.
+        Sample weights. If `None`, all samples are given the same weight.
 
     ignore_ties : bool, default=False
         Assume that there are no ties in y_score (which is likely to be the
@@ -1410,9 +1459,10 @@ def dcg_score(y_true, y_score, *, k=None,
     _check_dcg_target_type(y_true)
     return np.average(
         _dcg_sample_scores(
-            y_true, y_score, k=k, log_base=log_base,
-            ignore_ties=ignore_ties),
-        weights=sample_weight)
+            y_true, y_score, k=k, log_base=log_base, ignore_ties=ignore_ties
+        ),
+        weights=sample_weight,
+    )
 
 
 def _ndcg_sample_scores(y_true, y_score, k=None, ignore_ties=False):
@@ -1466,9 +1516,7 @@ def _ndcg_sample_scores(y_true, y_score, k=None, ignore_ties=False):
     return gain
 
 
-@_deprecate_positional_args
-def ndcg_score(y_true, y_score, *, k=None, sample_weight=None,
-               ignore_ties=False):
+def ndcg_score(y_true, y_score, *, k=None, sample_weight=None, ignore_ties=False):
     """Compute Normalized Discounted Cumulative Gain.
 
     Sum the true scores ranked in the order induced by the predicted scores,
@@ -1491,11 +1539,11 @@ def ndcg_score(y_true, y_score, *, k=None, sample_weight=None,
         "decision_function" on some classifiers).
 
     k : int, default=None
-        Only consider the highest k scores in the ranking. If None, use all
+        Only consider the highest k scores in the ranking. If `None`, use all
         outputs.
 
     sample_weight : ndarray of shape (n_samples,), default=None
-        Sample weights. If None, all samples are given the same weight.
+        Sample weights. If `None`, all samples are given the same weight.
 
     ignore_ties : bool, default=False
         Assume that there are no ties in y_score (which is likely to be the
@@ -1569,8 +1617,9 @@ def ndcg_score(y_true, y_score, *, k=None, sample_weight=None,
     return np.average(gain, weights=sample_weight)
 
 
-def top_k_accuracy_score(y_true, y_score, *, k=2, normalize=True,
-                         sample_weight=None, labels=None):
+def top_k_accuracy_score(
+    y_true, y_score, *, k=2, normalize=True, sample_weight=None, labels=None
+):
     """Top-k Accuracy classification score.
 
     This metric computes the number of times where the correct label is among
@@ -1649,10 +1698,10 @@ def top_k_accuracy_score(y_true, y_score, *, k=2, normalize=True,
     if y_type == "binary" and labels is not None and len(labels) > 2:
         y_type = "multiclass"
     y_score = check_array(y_score, ensure_2d=False)
-    y_score = column_or_1d(y_score) if y_type == 'binary' else y_score
+    y_score = column_or_1d(y_score) if y_type == "binary" else y_score
     check_consistent_length(y_true, y_score, sample_weight)
 
-    if y_type not in {'binary', 'multiclass'}:
+    if y_type not in {"binary", "multiclass"}:
         raise ValueError(
             f"y type must be 'binary' or 'multiclass', got '{y_type}' instead."
         )
@@ -1687,28 +1736,26 @@ def top_k_accuracy_score(y_true, y_score, *, k=2, normalize=True,
             )
 
         if len(np.setdiff1d(y_true, classes)):
-            raise ValueError(
-                "'y_true' contains labels not in parameter 'labels'."
-            )
+            raise ValueError("'y_true' contains labels not in parameter 'labels'.")
 
     if k >= n_classes:
         warnings.warn(
             f"'k' ({k}) greater than or equal to 'n_classes' ({n_classes}) "
             "will result in a perfect score and is therefore meaningless.",
-            UndefinedMetricWarning
+            UndefinedMetricWarning,
         )
 
     y_true_encoded = _encode(y_true, uniques=classes)
 
-    if y_type == 'binary':
+    if y_type == "binary":
         if k == 1:
-            threshold = .5 if y_score.min() >= 0 and y_score.max() <= 1 else 0
+            threshold = 0.5 if y_score.min() >= 0 and y_score.max() <= 1 else 0
             y_pred = (y_score > threshold).astype(np.int64)
             hits = y_pred == y_true_encoded
         else:
             hits = np.ones_like(y_score, dtype=np.bool_)
-    elif y_type == 'multiclass':
-        sorted_pred = np.argsort(y_score, axis=1, kind='mergesort')[:, ::-1]
+    elif y_type == "multiclass":
+        sorted_pred = np.argsort(y_score, axis=1, kind="mergesort")[:, ::-1]
         hits = (y_true_encoded == sorted_pred[:, :k].T).any(axis=0)
 
     if normalize:
